@@ -10,10 +10,10 @@ class Resource;
 class Policy {
   typedef Resource* (Policy::*method)(Simulator*);
   typedef UMAP<std::string, method> MethodMap;
-  
+
 public:
   std::string name;
-  
+
   Policy(Rcpp::Function resources, std::string policy) {}
   Policy(VEC<std::string> resources, std::string policy)
     : name(policy), resources(resources)
@@ -23,18 +23,17 @@ public:
     policies["first-available"]   = &Policy::policy_first_available;
     policies["random"]            = &Policy::policy_random;
   }
-  
+
   Resource* dispatch(Simulator* sim) {
     MethodMap::iterator x = policies.find(name);
-    if (x == policies.end())
-      Rcpp::stop("policy '" + name + "' not supported (typo?)");
+    if (x == policies.end()) Rcpp::stop("policy '" + name + "' not supported (typo?)");
     return ((*this).*(x->second))(sim);
   }
-  
+
 private:
   VEC<std::string> resources;
   MethodMap policies;
-  
+
   Resource* policy_shortest_queue(Simulator* sim);
   Resource* policy_round_robin(Simulator* sim);
   Resource* policy_first_available(Simulator* sim);
