@@ -84,7 +84,7 @@ void Task::run() {
 }
 
 void Arrival::reset() {
-  cancel_timeout();
+  cancel_renege();
   if (!--(*clones))
     delete clones;
   sim->unregister_arrival(this);
@@ -162,26 +162,10 @@ void Arrival::terminate(bool finished) {
   delete this;
 }
 
-void Arrival::renege(Activity* next) {
-  timer = NULL;
-  if (batch) {
-    if (batch->is_permanent())
-      return;
-    batch->erase(this);
-  }
-  if (!leave_resources() && !batch)
-    deactivate();
-  if (next) {
-    activity = next;
-    activate();
-  } else terminate(false);
-}
-
-int Arrival::set_attribute(std::string key, double value) {
+void Arrival::set_attribute(std::string key, double value) {
   attributes[key] = value;
   if (is_monitored() >= 2)
     sim->record_attribute(name, key, value);
-  return 0;
 }
 
 double Arrival::get_start(std::string name) {
@@ -195,8 +179,10 @@ double Arrival::get_start(std::string name) {
 }
 
 void Arrival::register_entity(Resource* ptr) {
-  if (is_monitored())
-      restime[ptr->name].start = sim->now();
+  if (is_monitored()) {
+    restime[ptr->name].start = sim->now();
+    restime[ptr->name].activity = 0;
+  }
   resources.insert(ptr);
 }
 
@@ -206,6 +192,40 @@ void Arrival::unregister_entity(Resource* ptr) {
   resources.erase(resources.find(ptr));
 }
 
+void Arrival::set_renege(std::string sig, Activity* next) {
+  cancel_renege();
+  signal = sig;
+  sim->subscribe(signal, this,
+                 boost::bind(&Arrival::renege, this, next));
+}
+
+void Arrival::cancel_renege() {
+  if (timer) {
+    timer->deactivate();
+    delete timer;
+    timer = NULL;
+  } else if (!signal.empty()) {
+    sim->unsubscribe(signal, this);
+    signal.clear();
+  }
+}
+
+void Arrival::renege(Activity* next) {
+  timer = NULL;
+  cancel_renege();
+  if (batch) {
+    if (batch->is_permanent())
+      return;
+    batch->erase(this);
+  }
+  if (!leave_resources() && !batch)
+    deactivate();
+  if (next) {
+    activity = next;
+    activate();
+  } else terminate(false);
+}
+
 void Arrival::report(std::string resource) {
   sim->record_release(name, restime[resource].start, restime[resource].activity, resource);
 }
@@ -230,11 +250,10 @@ void Batched::terminate(bool finished) {
   Arrival::terminate(finished);
 }
 
-int Batched::set_attribute(std::string key, double value) {
+void Batched::set_attribute(std::string key, double value) {
   attributes[key] = value;
   foreach_ (Arrival* arrival, arrivals)
     arrival->set_attribute(key, value);
-  return 0;
 }
 
 void Batched::erase(Arrival* arrival) {
