@@ -1,35 +1,5 @@
 context("select")
 
-test_that("resources are seized/released as expected", {
-  t0 <- create_trajectory() %>%
-    select("dummy0", id = 0) %>%
-    select(function() "dummy1", id = 1) %>%
-    seize_selected(-1, id = 0) %>%
-    timeout(1) %>%
-    seize_selected(function() 2, id = 1) %>%
-    timeout(1) %>%
-    release_selected(-1, id = 0) %>%
-    timeout(1) %>%
-    release_selected(function() 2, id = 1) %>%
-    timeout(1)
-
-  expect_output(print(t0))
-
-  env <- simmer(verbose = TRUE) %>%
-    add_resource("dummy0", 3, 0) %>%
-    add_resource("dummy1", 3, 0) %>%
-    add_generator("arrival", t0, at(0))
-
-  env %>% onestep() %>% onestep() %>% onestep()
-  expect_equal(env %>% get_server_count("dummy0"), 1)
-  env %>% onestep() %>% onestep()
-  expect_equal(env %>% get_server_count("dummy1"), 2)
-  env %>% onestep() %>% onestep() %>% onestep()
-  expect_equal(env %>% get_server_count("dummy0"), 0)
-  env %>% onestep() %>% onestep()
-  expect_equal(env %>% get_server_count("dummy1"), 0)
-})
-
 test_that("core selection algorithms work: shortest-queue", {
   t0 <- create_trajectory() %>% seize("r1", 1)
   t1 <- create_trajectory() %>% seize("r2", 1)
@@ -38,7 +8,7 @@ test_that("core selection algorithms work: shortest-queue", {
     select(c("r1", "r2", "r3"), policy = "shortest-queue") %>%
     seize_selected(1)
 
-  env <- simmer() %>%
+  env <- simmer(verbose = TRUE) %>%
     add_resource("r1", 2) %>%
     add_resource("r2", 3) %>%
     add_resource("r3", 1) %>%
@@ -65,7 +35,7 @@ test_that("core selection algorithms work: round-robin", {
     select(c("r1", "r2", "r3"), policy = "round-robin") %>%
     seize_selected(1)
 
-  env <- simmer() %>%
+  env <- simmer(verbose = TRUE) %>%
     add_resource("r1", 2) %>%
     add_resource("r2", 3) %>%
     add_resource("r3", 1) %>%
@@ -119,7 +89,7 @@ test_that("core selection algorithms work: random", {
     select(c("r1", "r2", "r3"), policy = "random") %>%
     seize_selected(1)
 
-  env <- simmer() %>%
+  env <- simmer(verbose = TRUE) %>%
     add_resource("r1", 2) %>%
     add_resource("r2", 3) %>%
     add_resource("r3", 1) %>%
@@ -151,7 +121,7 @@ test_that("custom selection algorithms work", {
     select(reverse_rr()) %>%
     seize_selected(1)
 
-  env <- simmer() %>%
+  env <- simmer(verbose = TRUE) %>%
     add_resource("r1", 2) %>%
     add_resource("r2", 3) %>%
     add_resource("r3", 1) %>%
