@@ -7,25 +7,26 @@ test_that("only valid types can be passed to functions", {
 
 })
 
-test_that("an attribute is correctly set and returned to a function that needs it", {
-
+test_that("an arrival attribute is correctly set and returned to a function", {
   t0 <- create_trajectory() %>%
     set_attribute("test", 123) %>%
-    timeout(function(attrs) print(attrs[["test"]]))
-
+    set_attribute("test", 456, global = TRUE) %>%
+    log_(function(attrs) paste0(attrs["test"])) %>%
+    log_(function(attrs, glb) paste0(attrs["test"], glb["test"]))
 
   expect_output({
     simmer(verbose = TRUE) %>%
       add_generator("entity", t0, at(0)) %>%
       run()
     },
-    "\\[1\\] 123"
+    ".*123.*123456"
   )
 })
 
 test_that("attributes can be correctly retrieved using get_mon_attributes()", {
   t0 <- create_trajectory() %>%
-    set_attribute("test", function() 123)
+    set_attribute("test", function() 123) %>%
+    set_attribute("test", function() 456, global = TRUE)
 
   env <-
     simmer(verbose = TRUE) %>%
@@ -34,14 +35,19 @@ test_that("attributes can be correctly retrieved using get_mon_attributes()", {
 
   attributes <- env %>% get_mon_attributes()
 
-  expect_equal(nrow(attributes), 1)
+  expect_equal(nrow(attributes), 2)
+  expect_equal(attributes[1, ]$name, "entity0")
   expect_equal(attributes[1, ]$key, "test")
   expect_equal(attributes[1, ]$value, 123)
+  expect_equal(attributes[2, ]$name, "")
+  expect_equal(attributes[2, ]$key, "test")
+  expect_equal(attributes[2, ]$value, 456)
 })
 
 test_that("the attribute dataframe is returned with the expected columns", {
   t0 <- create_trajectory() %>%
-    set_attribute("test", 123)
+    set_attribute("test", 123) %>%
+    set_attribute("test", 456, global = TRUE)
 
   env <-
     simmer(verbose = TRUE) %>%
@@ -51,13 +57,13 @@ test_that("the attribute dataframe is returned with the expected columns", {
   attributes <- env %>% get_mon_attributes()
 
   expect_true(all(sapply(colnames(attributes), function(x) x %in% colnames(attributes))))
-
 })
 
 
-test_that("attributes are returned empty when mon level is <2", {
+test_that("arrival attributes are returned empty when mon level is <2", {
   t0 <- create_trajectory() %>%
-    set_attribute("test", 123)
+    set_attribute("test", 123) %>%
+    set_attribute("test", 456, global = TRUE)
 
   env <-
     simmer(verbose = TRUE) %>%
@@ -66,5 +72,8 @@ test_that("attributes are returned empty when mon level is <2", {
 
   attributes <- env %>% get_mon_attributes()
 
-  expect_true(NROW(attributes) == 0)
+  expect_equal(nrow(attributes), 1)
+  expect_equal(attributes[1, ]$name, "")
+  expect_equal(attributes[1, ]$key, "test")
+  expect_equal(attributes[1, ]$value, 456)
 })
